#
# spec file for package python-pip-licenses
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-pip-licenses
Version:        4.4.0
Release:        1.3
Summary:        Python packages license list
License:        MIT
URL:            https://github.com/raimon49/pip-licenses
Source:         https://files.pythonhosted.org/packages/source/p/pip-licenses/pip-licenses-%{version}.tar.gz
BuildRequires:  %{python_module importlib_metadata}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-PrettyTable
Requires:       python-pip
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module PrettyTable}
BuildRequires:  %{python_module docutils}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module py}
BuildRequires:  %{python_module typing_extensions}
BuildRequires:  %{python_module wheel}
# /SECTION
%python_subpackages

%description
Dump the software license list of Python packages installed with pip.

%prep
%autosetup -p1 -n pip-licenses-%{version}

sed -i '/addopts/d' setup.cfg
sed -i '/pytest-/d' setup.cfg
sed -i '1{/^#!/d}' piplicenses.py

%build
%pyproject_wheel

%install
%pyproject_install
%python_clone -a %{buildroot}%{_bindir}/pip-licenses
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
export LANG=en_US.UTF-8
# gh#raimon49/pip-licenses#120 for test_from_all
donttest="test_from_all"
%pytest -k "not ($donttest)"
%python_expand PYTHONPATH=%{buildroot}%{$python_sitelib} %{buildroot}%{_bindir}/pip-licenses-%{$python_bin_suffix} -s

%post
%python_install_alternative pip-licenses

%postun
%python_uninstall_alternative pip-licenses

%files %{python_files}
%doc CHANGELOG.md README.md
%license LICENSE
%python_alternative %{_bindir}/pip-licenses
%{python_sitelib}/piplicenses.py
%{python_sitelib}/pip_licenses-%{version}*-info
%pycache_only %{python_sitelib}/__pycache__/piplicenses.*pyc

%changelog
* Sun Jun 30 2024 Dirk Müller <dmueller@suse.com>
- update to 4.4.0:
  * Implement new option `--partial-match`
- drop 0001-Fix-test_different_python-under-pyhon-3.12.patch
  (upstream)
* Sat Mar 16 2024 Jaime Marquínez Ferrándiz <jaime.marquinez.ferrandiz@fastmail.net>
- Add 0001-Fix-test_different_python-under-pyhon-3.12.patch
* Tue Jan 23 2024 Daniel Garcia <daniel.garcia@suse.com>
- Remove not needed test ignore, fixed upstream.
* Mon Jan 22 2024 Dirk Müller <dmueller@suse.com>
- update to 4.3.4:
  * Maintain to pass test with wcwidth>=0.2.10
* Thu Jan 18 2024 Daniel Garcia <daniel.garcia@suse.com>
- Update to version 4.3.3:
  * Always terminate --allow-only and --fail-on messages with a newline
  * Always terminate files created with --output-file with a newline
- Ignore broken test with latest version of wcwidth,
  gh#raimon49/pip-licenses#178
* Thu Jun  1 2023 Dirk Müller <dmueller@suse.com>
- update to 4.3.2:
  * Better Handling extracting URLs from `Project-URL`
* Thu May  4 2023 Daniel Garcia <daniel.garcia@suse.com>
- Update to 4.3.1:
  * Fix to treat package names as normalized as in PEP 503 with
  - -packages and --ignore-packages option
- 4.3.0:
  * Implement new option --no-version
* Wed Apr 12 2023 Matej Cepl <mcepl@suse.com>
- Update to 4.2.0:
  - Implement new option --with-maintainers
  - Implement new option --python
  - Allow version spec in --ignore-packages parameters
  - When the Author field is UNKNOWN, the output is automatically
    completed from Author-email
  - When the home-page field is UNKNOWN, the output is
    automatically completed from Project-URL
- Update to 4.1.0:
  - Support case-insensitive license name matching around
  - -fail-on and --allow-only parameters
* Mon Feb  6 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.3:
  * Escape unicode output (to e.g. &#123;) in the html output
  * Add type annotations and code formatter
- Add missing BuildRequires to fix test failures.
* Sat Dec  3 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 4.0.1
  * Fix “pip-licenses” is missing in output of pip-licenses --with-system option
* Sun Nov  6 2022 Matej Cepl <mcepl@suse.com>
- Update to 4.0.0:
  - Support for Python 3.11
  - Dropped support Python 3.7
  - Migrate Docker base image from Alpine to Debian 11-slim
  - Breaking changes
  - Does not work with PTable and depends on prettytable
  - Depend on importlib_metadata rather than pip
- Remove unnecessary no-pip-internal.patch.
* Sat Feb 26 2022 Matej Cepl <mcepl@suse.com>
- Update to 3.5.2:
  - Ignore spaces around --fail-on and --allow-only parameters
  - Fix the order in which multiple licenses are output
  - Handle multiple licenses better with options --fail-on and
  - -allow-only
  - Small change in output method for multiple licenses, change
    the separator from comma to semicolon
    Up to 3.4.0: Python Software Foundation License, MIT License
    3.5.0 or later: Python Software Foundation License; MIT License
  - Implement new option --packages
  - Fix license summary refer to --from option
  - Improves the readability of the help command
  - Implement new option --from=all
  - Change license notation under SPDX license identifier style
  - Implement new option for use in continuous integration
  - -fail-on
  - -allow-only
- Skip failing tests gh#raimon49/pip-licenses#120
- Add no-pip-internal.patch replace missing
  get_installed_distributions() method in modern pip.
* Tue Nov 24 2020 John Vandenberg <jayvdb@gmail.com>
- Update to v3.0.0
  * Change default behavior to `--from=mixed`
* Sun Oct  4 2020 John Vandenberg <jayvdb@gmail.com>
- Add missing runtime dependency on pip
- Update to v3.1.1
  * Implement new option for manage unicode characters
    + `--filter-strings`
    + `--filter-code-page`
- from v2.2.1
  * Fixed the file that is selected when multiple matches are made
    with `LICENSE*` with run `--with-license-file`
- from v2.2.0
  * Implement new option `--with-notice-file`
  * Added to find British style file name `LICENCE` with run
    `--with-license-file`
* Mon May 18 2020 Matej Cepl <mcepl@suse.com>
- Don't use %%python3_only command, but properly use alternatives.
* Mon Mar 16 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 2.1.1
  * Suppress errors when opening license files
  * Implement new option --format=plain-vertical
  * Support for outputting license file named COPYING *
  * Better license file open handling in Python 3
  * Dropped support Python 2.7
  * Options like --format-* were marked obsolete
  * Implement new option --no-license-path
* Sun Dec 22 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v1.18.0
* Tue Dec 17 2019 John Vandenberg <jayvdb@gmail.com>
- Update to v0.17.0
* Wed May  8 2019 John Vandenberg <jayvdb@gmail.com>
- Initial spec for v1.13.0
